Further Topics
==============

This section contains a variety of tutorials that show some more in depth
capabilities of the axelrod library

Contents:

.. toctree::
   :maxdepth: 2

   classification_of_strategies.rst
   creating_matches.rst
   morality_metrics.rst
   probabilistict_end_tournaments.rst
